{% load staticfiles %}
<script src="{% static 'js/jquery.js' %}"></script>
<script src="{% static 'js/csrf_token.js' %}"></script>
<script src="{% static 'js/json2.js' %}"></script>
<script src="{% static 'js/underscore.js' %}"></script>
<script src="{% static 'js/backbone.js' %}"></script>
<script src="{% static 'js/backbone.wreqr.js' %}"></script>
<script src="{% static 'js/backbone.babysitter.js' %}"></script>
<script src="{% static 'js/backbone.marionette.min.js' %}"></script>
<script src="{% static 'js/bootstrap.min.js' %}"></script>
